DynamicAction enum

Actions that can be returned from dynamic list handlers.

Inheritance
Available extensions

Values

none → const DynamicAction

Do nothing special.

rebuild → const DynamicAction

Rebuild the item list (e.g., after expand/collapse).

rebuildAndReset → const DynamicAction

Rebuild the item list and reset navigation to first item.

confirm → const DynamicAction

Confirm and exit with the current item.

cancel → const DynamicAction

Cancel and exit.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DynamicAction>
A constant List of the values in this enum, in order of their declaration.