FrameRenderer class

Helpers to render titles and horizontal border lines consistently.

Constructors

FrameRenderer()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

bottomLine(String title, PromptTheme theme) String
bottomLineColored(String title, PromptTheme theme, String color) String
Bottom line with a custom color.
connectorLine(String title, PromptTheme theme) String
plainTitle(String title, PromptTheme theme) String
Plain title with accent color.
plainTitleColored(String title, PromptTheme theme, String color) String
Plain title with a custom color.
titleWithBorders(String title, PromptTheme theme) String
Properly balanced title: ╭─ Title ─╮
titleWithBordersColored(String title, PromptTheme theme, String color) String
Title with themed borders but custom color.