GridRow<T> class

A row of items in a grid.

Constructors

GridRow({required int row, required int startIndex, required List<T> items, required bool isLastRow})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
Whether this row is empty.
no setter
isLastRow bool
Whether this is the last row.
final
items List<T>
Items in this row.
final
length int
Number of items in this row.
no setter
row int
Row index (0-indexed).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startIndex int
Start index of this row in the full item list.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited