HintStyle enum

Hint display style options for keyboard bindings.

Inheritance
Available extensions

Values

bullets → const HintStyle

Bullet-style hints on a single line.

grid → const HintStyle

Grid-style hints with aligned columns.

inline → const HintStyle

Inline comma-separated hints in parentheses.

none → const HintStyle

No hints displayed.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<HintStyle>
A constant List of the values in this enum, in order of their declaration.