TerminalControl class

Terminal utilities used across components and prompts to manage raw mode and input.

Constructors

TerminalControl()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

clearAndHome() → void
Clears the screen and moves cursor to home position.
enterRaw() TerminalModeState
Puts stdin into raw mode (no echo, no line buffering) and returns a TerminalModeState that can be used to restore the original settings.
hideCursor() → void
Hides the cursor.
showCursor() → void
Shows the cursor.
tryReadNextByte({Duration delay = const Duration(milliseconds: 2)}) int?
Attempts to read the next byte for multi-byte escape sequences.