ErrorTerminalInput class
- Implemented types
Constructors
Properties
- echoMode ↔ bool
-
Whether input characters are echoed to output.
getter/setter pairoverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasTerminal → bool
-
Whether a terminal is attached to stdin.
no setteroverride
- lineMode ↔ bool
-
Whether input is line-buffered.
getter/setter pairoverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readByteSync(
) → int -
Reads a single byte synchronously from input.
override
-
readLineSync(
) → String? -
Reads a line synchronously from input.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited