echoMode property
Whether input characters are echoed to output.
In raw mode, this should be false to prevent double-printing.
Implementation
@override
bool get echoMode => throw Exception('ErrorTerminal: echoMode get');
Whether input characters are echoed to output.
In raw mode, this should be false to prevent double-printing.
@override
bool get echoMode => throw Exception('ErrorTerminal: echoMode get');