lineMode property
Whether input is line-buffered.
In raw mode, this should be false for immediate character access.
Implementation
@override
bool get lineMode => throw Exception('ErrorTerminal: lineMode get');
Whether input is line-buffered.
In raw mode, this should be false for immediate character access.
@override
bool get lineMode => throw Exception('ErrorTerminal: lineMode get');