echoMode property
Whether input characters are echoed to output.
In raw mode, this should be false to prevent double-printing.
Implementation
@override
bool get echoMode {
_calls.add('input.echoMode.get');
return _echoMode;
}
Whether input characters are echoed to output.
In raw mode, this should be false to prevent double-printing.
@override
bool get echoMode {
_calls.add('input.echoMode.get');
return _echoMode;
}