EndBehavior class
Configuration for end-of-prompt behavior.
Constructors
- EndBehavior({bool clearOnEnd = true})
-
const
Properties
- clearOnEnd → bool
-
Whether to clear the rendered output when the prompt ends.
If false, the final render remains visible.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- clear → const EndBehavior
- Default: clears prompt output when done (returns to clean terminal).
- persist → const EndBehavior
- Keeps the final render visible after the prompt ends.