TerminalModeState class
Captures original terminal state and restores it on restore.
Constructors
- TerminalModeState({required bool origEcho, required bool origLineMode})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- origEcho → bool
-
final
- origLineMode → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
restore(
) → void - Restores the terminal's echo and line mode flags to their original values.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited