ErrorTerminal class
A terminal that always throws to test error handling.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- input → TerminalInput
-
The input stream for reading key events and managing terminal modes.
no setteroverride
- output → TerminalOutput
-
The output stream for writing content and querying terminal dimensions.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited