ErrorTerminalOutput class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
hasTerminal
→ bool
-
Whether a terminal is attached to stdout.
no setteroverride
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
terminalColumns
→ int
-
The number of columns in the terminal.
no setteroverride
-
terminalLines
→ int
-
The number of lines (rows) in the terminal.
no setteroverride
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
write(Object? object)
→ void
-
Writes an object to the output without a trailing newline.
override
-
writeln([Object? object = ''])
→ void
-
Writes an object to the output followed by a newline.
override